==> kubernetes-model-1.0.6-sources.jar: annotations/io/fabric8/kubernetes/api/model/RBDVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class RBDVolumeSourceBuilder extends RBDVolumeSourceFluent<RBDVolumeSourceBuilder> implements VisitableBuilder<RBDVolumeSource,RBDVolumeSourceBuilder>{

     RBDVolumeSourceFluent<?> fluent;
public RBDVolumeSourceBuilder(){
    this(new RBDVolumeSource());
}
public RBDVolumeSourceBuilder( RBDVolumeSourceFluent<?> fluent ){
    this(fluent, new RBDVolumeSource());
}
public RBDVolumeSourceBuilder( RBDVolumeSourceFluent<?> fluent , RBDVolumeSource instance ){
    this.fluent = fluent; fluent.withFsType(instance.getFsType()); fluent.withImage(instance.getImage()); fluent.withKeyring(instance.getKeyring()); fluent.withMonitors(instance.getMonitors()); fluent.withPool(instance.getPool()); fluent.withReadOnly(instance.getReadOnly()); fluent.withSecretRef(instance.getSecretRef()); fluent.withUser(instance.getUser()); 
}
public RBDVolumeSourceBuilder( RBDVolumeSource instance ){
    this.fluent = this; this.withFsType(instance.getFsType()); this.withImage(instance.getImage()); this.withKeyring(instance.getKeyring()); this.withMonitors(instance.getMonitors()); this.withPool(instance.getPool()); this.withReadOnly(instance.getReadOnly()); this.withSecretRef(instance.getSecretRef()); this.withUser(instance.getUser()); 
}

public EditableRBDVolumeSource build(){
    EditableRBDVolumeSource buildable = new EditableRBDVolumeSource(fluent.getFsType(),fluent.getImage(),fluent.getKeyring(),fluent.getMonitors(),fluent.getPool(),fluent.isReadOnly(),fluent.getSecretRef(),fluent.getUser());
validate(buildable);
return buildable;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.11-sources.jar: annotations/io/fabric8/kubernetes/api/model/RBDVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class RBDVolumeSourceBuilder extends RBDVolumeSourceFluent<RBDVolumeSourceBuilder> implements VisitableBuilder<RBDVolumeSource,RBDVolumeSourceBuilder>{

     RBDVolumeSourceFluent<?> fluent;
public RBDVolumeSourceBuilder(){
    this(new RBDVolumeSource());
}
public RBDVolumeSourceBuilder( RBDVolumeSourceFluent<?> fluent ){
    this(fluent, new RBDVolumeSource());
}
public RBDVolumeSourceBuilder( RBDVolumeSourceFluent<?> fluent , RBDVolumeSource instance ){
    this.fluent = fluent; fluent.withFsType(instance.getFsType()); fluent.withImage(instance.getImage()); fluent.withKeyring(instance.getKeyring()); fluent.withMonitors(instance.getMonitors()); fluent.withPool(instance.getPool()); fluent.withReadOnly(instance.getReadOnly()); fluent.withSecretRef(instance.getSecretRef()); fluent.withUser(instance.getUser()); 
}
public RBDVolumeSourceBuilder( RBDVolumeSource instance ){
    this.fluent = this; this.withFsType(instance.getFsType()); this.withImage(instance.getImage()); this.withKeyring(instance.getKeyring()); this.withMonitors(instance.getMonitors()); this.withPool(instance.getPool()); this.withReadOnly(instance.getReadOnly()); this.withSecretRef(instance.getSecretRef()); this.withUser(instance.getUser()); 
}

public EditableRBDVolumeSource build(){
    EditableRBDVolumeSource buildable = new EditableRBDVolumeSource(fluent.getFsType(),fluent.getImage(),fluent.getKeyring(),fluent.getMonitors(),fluent.getPool(),fluent.isReadOnly(),fluent.getSecretRef(),fluent.getUser());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
RBDVolumeSourceBuilder that = (RBDVolumeSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
